% This program solves a simple competition model between rabbits (R) and
% foxes (S) given by:
%
%    R' =  a*R*(1 - (1/Lr)*R - c*S)
%    S' = -b*S*(1 - (1/Ls)*S - d*R)
%
% In this example, the parameters are chosen so that:
%    (1) The co-existence equilibrium point is the only stable one.
%
% Note that is uses GLOBAL variables to pass parameter values onto the
% integration functioin.
clear
rng(0)

%%% Set parameters.
global a b c d Lr Ls
a = 0.2;
b = 0.1;
c  = 0.01;
d  = 0.02;
Lr = 20;
Ls = 10;

%%% Find equilibrium solution:
equil = [1/Lr,c;d,1/Ls]\[1;1];
Rhat = equil(1);
Shat = equil(2);
fprintf(1,'Equilibrium point:   Rhat = %6.2f    Shat = %6.2f\n',Rhat,Shat)

%%% Set initial condition.
R0 = 6;
S0 = 1.5;

%%% Solve ODE numerically.
[tt,yy] = ode45('odefun3',[0,300],[R0;S0]);
rr = yy(:,1);
ss = yy(:,2);

%%% Draw phase diagram.
figure(1)
subplot(1,2,1)
hold off
[RR,SS] = meshgrid(linspace(0,25,15),linspace(0,12,15));
quiver(RR,SS,a*RR.*(1 - (1/Lr)*RR - c*SS),...
             b*SS.*(1 - (1/Ls)*SS - d*RR),'k')
hold on
plot(rr,ss,'m',...
     R0,S0,'k.',...
     [0,0,Lr,equil(1)],[0,Ls,0,equil(2)],'g.','MarkerSize',30,'LineWidth',2)
xlabel('R')
ylabel('S')
legend('phase field','solution','initial cond','equil points')

%%% Draw solutions as functions of t:
subplot(1,2,2)
plot(tt,rr,'b',...
     tt,ss,'r','LineWidth',2)
xlabel('t')
legend('R','S')